==========================
Grand Challenge API Client
==========================


.. image:: https://img.shields.io/pypi/v/gcapi.svg
        :target: https://pypi.python.org/pypi/gcapi

.. image:: https://img.shields.io/travis/DIAGNijmegen/gcapi.svg
        :target: https://travis-ci.org/DIAGNijmegen/gcapi

.. image:: https://readthedocs.org/projects/gcapi/badge/?version=latest
        :target: https://gcapi.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/DIAGNijmegen/gcapi/shield.svg
     :target: https://pyup.io/repos/github/DIAGNijmegen/gcapi/
     :alt: Updates



Python client for the grand-challenge.org API


* Free software: Apache Software License 2.0
* Documentation: https://gcapi.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
